==> plugin-api-1.3.2-sources.jar: com/xebialabs/deployit/ci/artifact/mapping/DeployableArtifactMapping.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.ci.artifact.mapping;

import com.xebialabs.deployit.ConfigurationItemProperty;
import com.xebialabs.deployit.ConfigurationItemProperty.Size;
import com.xebialabs.deployit.ci.artifact.DeployableArtifact;
import com.xebialabs.deployit.ci.mapping.KeyValuePair;
import com.xebialabs.deployit.ci.mapping.Mapping;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * A mapping of a {@link DeployableArtifact} to any kind of middleware.
 */
@SuppressWarnings("serial")
public abstract class DeployableArtifactMapping<S extends DeployableArtifact, T extends Serializable> extends Mapping<S, T> {

	@ConfigurationItemProperty(description = "Values for placeholders in the deployable artifact that are to be replaced. The key is the placeholder name. Example: Key: DATABASE_USER, Value: testUser", size = Size.LARGE)
	private List<KeyValuePair> keyValuePairs = new ArrayList<KeyValuePair>();

	public DeployableArtifactMapping() {}

	public DeployableArtifactMapping(S source, T target) {
		super(source, target);
	}

	public List<KeyValuePair> getKeyValuePairs() {
		return keyValuePairs;
	}

	public void setKeyValuePairs(List<KeyValuePair> keyValuePairs) {
		this.keyValuePairs = keyValuePairs;
	}

	public void addKeyValuePair(KeyValuePair keyValuePair) {
		if (keyValuePairs == null) {
			keyValuePairs = new ArrayList<KeyValuePair>();
		}
		keyValuePairs.add(keyValuePair);
	}
}

==> plugin-api-1.4-sources.jar: com/xebialabs/deployit/ci/artifact/mapping/DeployableArtifactMapping.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.ci.artifact.mapping;

import com.xebialabs.deployit.ConfigurationItemPlaceholderFormat;
import com.xebialabs.deployit.ConfigurationItemPlaceholders;
import com.xebialabs.deployit.ConfigurationItemProperty;
import com.xebialabs.deployit.ci.artifact.DeployableArtifact;
import com.xebialabs.deployit.ci.mapping.KeyValuePair;
import com.xebialabs.deployit.ci.mapping.Mapping;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * A mapping of a {@link DeployableArtifact} to any kind of middleware.
 */
@SuppressWarnings("serial")
public abstract class DeployableArtifactMapping<S extends DeployableArtifact, T extends Serializable> extends Mapping<S, T> {

	@ConfigurationItemProperty
    @ConfigurationItemPlaceholders
	private List<KeyValuePair> keyValuePairs = new ArrayList<KeyValuePair>();

	@ConfigurationItemProperty
	@ConfigurationItemPlaceholderFormat
	private PlaceholderFormat placeholderFormat = PlaceholderFormat.SPRING;

	public DeployableArtifactMapping() {
	}

	public DeployableArtifactMapping(S source, T target) {
		super(source, target);
	}

	public List<KeyValuePair> getKeyValuePairs() {
		return keyValuePairs;
	}

	public void setKeyValuePairs(List<KeyValuePair> placeholders) {
		this.keyValuePairs = placeholders;
	}

	public void addKeyValuePair(KeyValuePair keyValuePair) {
		if (keyValuePairs == null) {
			keyValuePairs = new ArrayList<KeyValuePair>();
		}
		keyValuePairs.add(keyValuePair);
	}

	public PlaceholderFormat getPlaceholderFormat() {
		return (placeholderFormat == null ? PlaceholderFormat.SPRING : placeholderFormat);
	}

	public void setPlaceholderFormat(PlaceholderFormat placeholderFormat) {
		this.placeholderFormat = placeholderFormat;
	}

	public Map<String, String> getKeyValueMap() {
		return KeyValuePair.toMap(keyValuePairs);
	}
}
